# -*- coding: utf-8 -*-

import autopath
from pyeole.pkg import EolePkg, PackageNotFoundError
import apt

from py.test import raises

repo = None
mode = None

def setup_module(module):
    try:
        module.repo = EolePkg("apt", test=True)
        module.mode = "apt"
    except ImportError:
        try:
            module.repo = EolePkg("yum", test=True)
            module.mode = "yum"
        except ImportError:
            raise ImportError("No package manager module found")

def test_import():
    assert mode != None

def test_create_package_manager():
    assert isinstance(repo, EolePkg)

def test_get_existing_package():
    pkgname = "tree"
    pkg = repo.get_package(pkgname)
    if mode == "apt":
        assert isinstance(pkg, apt.Package)
    elif mode == "yum":
        assert isinstance(pkg, yum.Package)

def test_get_nonexistant_package():
    pkgname = "nonexistent"
    with raises(PackageNotFoundError):
        pkg = repo.get_package(pkgname)

def test_install():
    pkgname = "tree"
    repo.pkgmgr.set_test_run(True)
    repo.install(pkgname)

def test_remove():
    pkgname = "tree"
    repo.pkgmgr.set_test_run(True)
    repo.remove(pkgname)

def test_update():
    repo.update()

def test_upgrade():
    repo.pkgmgr.set_test_run(True)
    repo.upgrade()

def test_get_depends():
    pkgname = "libc6"
    deps = ['libc-bin', 'libgcc1', 'tzdata']
    dp_list = repo.get_depends(pkgname)
    assert dp_list == deps
